@@ -4,6 +4,9 @@
     SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
+#ifndef KCMTEST_H
+#define KCMTEST_H
+
 #include <QObject>
 #include <QVariantList>
 
@@ -13,3 +16,5 @@ class KCMTest : public QObject
 public:
     explicit KCMTest(QObject *parent, const QVariantList &foo = QVariantList());
 };
+
+#endif
