@@ -10,14 +10,16 @@
 
 #include "kcmoduleinfo.h"
 
+#if KCMUTILS_BUILD_DEPRECATED_SINCE(5, 88)
+
 #include <kcmutils_debug.h>
 
 #include <QVariant>
 
 #include <KDesktopFile>
 
-#include <KPluginInfo>
 #include <KLocalizedString>
+#include <KPluginInfo>
 
 class Q_DECL_HIDDEN KCModuleInfo::Private
 {
@@ -27,9 +29,9 @@ public:
     Private(const KService::Ptr &);
 
     QStringList keywords;
-    QString     name, icon, lib, handle, fileName, doc, comment;
-    bool        allLoaded = false;
-    int         weight = 100;
+    QString name, icon, lib, handle, fileName, doc, comment;
+    bool allLoaded = false;
+    int weight = 100;
 
     // For real C++ plugins
     KPluginInfo pluginInfo;
@@ -67,9 +69,9 @@ KCModuleInfo::Private::Private(const KPluginInfo &pluginInfo)
 }
 
 KCModuleInfo::Private::Private(const KService::Ptr &service)
-    : allLoaded(false),
-      pluginInfo(),
-      service(service)
+    : allLoaded(false)
+    , pluginInfo()
+    , service(service)
 {
     if (!service) {
         return;
@@ -122,7 +124,7 @@ bool KCModuleInfo::operator==(const KCModuleInfo &rhs) const
 
 bool KCModuleInfo::operator!=(const KCModuleInfo &rhs) const
 {
-    return ! operator==(rhs);
+    return !operator==(rhs);
 }
 
 KCModuleInfo::~KCModuleInfo()
@@ -197,11 +199,11 @@ KService::Ptr KCModuleInfo::service() const
     if (!d->pluginInfo.isValid()) {
         return {};
     }
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
-QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
+    QT_WARNING_PUSH
+    QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+    QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
     return d->pluginInfo.service();
-QT_WARNING_POP
+    QT_WARNING_POP
 }
 
 KPluginInfo KCModuleInfo::pluginInfo() const
@@ -233,6 +235,7 @@ QString KCModuleInfo::docPath() const
     return d->doc;
 }
 
+#if KCMUTILS_BUILD_DEPRECATED_SINCE(5, 85)
 QString KCModuleInfo::handle() const
 {
     if (!d->allLoaded) {
@@ -241,6 +244,7 @@ QString KCModuleInfo::handle() const
 
     return d->handle;
 }
+#endif
 
 int KCModuleInfo::weight() const
 {
@@ -260,3 +264,4 @@ QVariant KCModuleInfo::property(const QString &key) const
     }
 }
 
+#endif
