@@ -37,7 +37,6 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KPageWidgetModel>
-#include <KPluginInfo>
 
 bool KCMultiDialogPrivate::resolveChanges(KCModuleProxy *currentProxy)
 {
@@ -47,19 +46,19 @@ bool KCMultiDialogPrivate::resolveChanges(KCModuleProxy *currentProxy)
     }
 
     // Let the user decide
-    const int queryUser = KMessageBox::warningYesNoCancel(q,
-                                                          i18n("The settings of the current module have changed.\n"
-                                                               "Do you want to apply the changes or discard them?"),
-                                                          i18n("Apply Settings"),
-                                                          KStandardGuiItem::apply(),
-                                                          KStandardGuiItem::discard(),
-                                                          KStandardGuiItem::cancel());
+    const int queryUser = KMessageBox::warningTwoActionsCancel(q,
+                                                               i18n("The settings of the current module have changed.\n"
+                                                                    "Do you want to apply the changes or discard them?"),
+                                                               i18n("Apply Settings"),
+                                                               KStandardGuiItem::apply(),
+                                                               KStandardGuiItem::discard(),
+                                                               KStandardGuiItem::cancel());
 
     switch (queryUser) {
-    case KMessageBox::Yes:
+    case KMessageBox::PrimaryAction:
         return moduleSave(currentProxy);
 
-    case KMessageBox::No:
+    case KMessageBox::SecondaryAction:
         currentProxy->load();
         return true;
 
