@@ -6,9 +6,10 @@
 */
 
 #include "ksettingswidgetadaptor.h"
-#include <QString>
 #include <QGuiApplication>
+#include <QString>
 
+#if KCMUTILS_BUILD_DEPRECATED_SINCE(5, 82)
 KSettingsWidgetAdaptor::KSettingsWidgetAdaptor(QObject *parent)
     : QObject(parent)
 {
@@ -23,3 +24,6 @@ QString KSettingsWidgetAdaptor::applicationName()
     return QCoreApplication::applicationName();
 }
 
+#include "moc_ksettingswidgetadaptor.cpp"
+
+#endif
